@@ -138,6 +138,37 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteApplication(self, request):
+        """服务删除
+          - 停止当前运行服务
+          - 删除服务相关资源
+          - 删除服务
+
+        :param request: Request instance for DeleteApplication.
+        :type request: :class:`tencentcloud.tem.v20210701.models.DeleteApplicationRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.DeleteApplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteApplication", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteApplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteIngress(self, request):
         """删除 Ingress 规则
 
@@ -418,6 +449,34 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyApplicationReplicas(self, request):
+        """修改应用实例数量
+
+        :param request: Request instance for ModifyApplicationReplicas.
+        :type request: :class:`tencentcloud.tem.v20210701.models.ModifyApplicationReplicasRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.ModifyApplicationReplicasResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyApplicationReplicas", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyApplicationReplicasResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyEnvironment(self, request):
         """编辑环境
 
@@ -474,6 +533,34 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RestartApplication(self, request):
+        """服务重启
+
+        :param request: Request instance for RestartApplication.
+        :type request: :class:`tencentcloud.tem.v20210701.models.RestartApplicationRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.RestartApplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RestartApplication", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RestartApplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RestartApplicationPod(self, request):
         """重启应用实例
 
@@ -551,6 +638,62 @@ class TemClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RollingUpdateApplicationByVersion(self, request):
+        """更新应用部署版本
+
+        :param request: Request instance for RollingUpdateApplicationByVersion.
+        :type request: :class:`tencentcloud.tem.v20210701.models.RollingUpdateApplicationByVersionRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.RollingUpdateApplicationByVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RollingUpdateApplicationByVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RollingUpdateApplicationByVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopApplication(self, request):
+        """服务停止
+
+        :param request: Request instance for StopApplication.
+        :type request: :class:`tencentcloud.tem.v20210701.models.StopApplicationRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.StopApplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StopApplication", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopApplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
